# vancalculator Library Package

This project is developed to fullfil the requirement of Udacity AWS Machine Learning Foundations Course.<br/>
This is an Object Oriented Programming Project developed in Python build for the calculation of mode, median, Gaussian and binomial distribution.<br/><br/>
It is able to be downloaded at PyPi: vancalculator<br/><br/>
Search in Link: [PyPi Website](https://pypi.org/)<br/>
Exact Package Link: [vancalculator Library](https://pypi.org/project/vancalculator/0.0.1/)<br/>
Or<br/>
`pip install vancalculator`<br/><br/>

Github Link: [vancalculator-Package](https://github.com/Laikaiyong/Vandyck-Pycalculator-Package)<br/><br/>

The package is able to calculate:<br/><br/>

**General**

- mode
- median
  <br/><br/>

Version: 0.0.2<br/><br/>

**Gaussian**

- mean
- standard deviation
- Gaussian Graph Visualization
- PDF Graph view
- Add two Gaussians together
- Display characteristics of Gaussian
  <br/><br/>

**Binomial**

- mean
- standard deviation
- Binomial Graph Visualization
- PDF Graph view
- Add two Binomials together
- Display characteristics of Binomial
  <br/><br/>

Usage:

```py
import vancalculator
```
